@@ -37,7 +37,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #endif
 
 // KDE
-#include <KIO/NetAccess>
 #include <KActionCategory>
 #include <KActionCollection>
 #include <KFileDialog>
@@ -1550,6 +1549,8 @@ void MainWindow::resizeEvent(QResizeEvent* event)
 
 bool MainWindow::eventFilter(QObject *obj, QEvent *event)
 {
+    Q_UNUSED(obj);
+    Q_UNUSED(event);
 #ifdef Q_OS_OSX
     /**
     * handle Mac OS X file open events (only exist on OS X)
